---
search:
  exclude: true
---
# コード例

リポジトリの [code examples](https://github.com/openai/openai-agents-python/tree/main/examples) セクションで、 SDK のさまざまなサンプル実装をご覧ください。code examples は、異なるパターンや機能を示す複数のカテゴリーに整理されています。


## カテゴリー

-  **[エージェントパターン (agent_patterns)](https://github.com/openai/openai-agents-python/tree/main/examples/agent_patterns):**
  このカテゴリーの例では、次のような一般的な エージェント の設計パターンを示します。

    - 決定的なワークフロー
    - ツールとしての エージェント
    - エージェント の並列実行

-  **[基本 (basic)](https://github.com/openai/openai-agents-python/tree/main/examples/basic):**
  これらの例は、次のような SDK の基礎的な機能を紹介します。

    - 動的な システムプロンプト
    - ストリーミング 出力
    - ライフサイクルイベント

-  **[ツールのサンプルコード (tools)](https://github.com/openai/openai-agents-python/tree/main/examples/tools):**
  Web 検索 や ファイル検索 などの OpenAI がホストするツール の実装方法と、それらを エージェント に統合する方法を学べます。

-  **[モデルプロバイダー (model_providers)](https://github.com/openai/openai-agents-python/tree/main/examples/model_providers):**
  SDK で OpenAI 以外のモデルを使用する方法を探ります。

-  **[ハンドオフ (handoffs)](https://github.com/openai/openai-agents-python/tree/main/examples/handoffs):**
  エージェント の ハンドオフ の実用例をご覧ください。

-  **[MCP (mcp)](https://github.com/openai/openai-agents-python/tree/main/examples/mcp):**
  MCP で エージェント を構築する方法を学べます。

-  **[customer_service](https://github.com/openai/openai-agents-python/tree/main/examples/customer_service)** と **[research_bot](https://github.com/openai/openai-agents-python/tree/main/examples/research_bot):**
  実世界のアプリケーションを示す、さらに作り込まれたサンプルが 2 つあります。

    -  **customer_service** : 航空会社向けのカスタマーサービス システムのサンプル。
    -  **research_bot** : シンプルな ディープリサーチ のクローン。

-  **[音声 (voice)](https://github.com/openai/openai-agents-python/tree/main/examples/voice):**
  TTS と STT モデルを用いた音声 エージェント の例をご覧ください。

-  **[リアルタイム (realtime)](https://github.com/openai/openai-agents-python/tree/main/examples/realtime):**
  SDK を使ってリアルタイム体験を構築する方法を示す code examples。